@echo off

setlocal ENABLEDELAYEDEXPANSION

if NOT DEFINED java_home goto MISSING_JAVA_HOME

if "%1" == "" goto BAD_CMD

set batchDrive=%~d0
%batchDrive%

set batchDir=%~p0
cd %batchDir%
cd ..
set rootDir=%cd%

if NOT DEFINED HOSTNAME for /f %%i in ('hostname') do set HOSTNAME=%%i

set orb=-Djava.endorsed.dirs=lib\endorsed -Dorg.omg.CORBA.ORBClass=org.jacorb.orb.ORB -Dorg.omg.CORBA.ORBSingletonClass=org.jacorb.orb.ORBSingleton
set derby_cfg=-Dderby.storage.pageSize=4096 -Dderby.storage.pageCacheSize=40
set derby_log=-Dderby.stream.error.file="%rootDir%"\logs\derby.log

rem ====================================================
rem Determine which service runner to use
rem ====================================================

set serviceExe=bin\JavaService-x86.exe
"%JAVA_HOME%\bin\java" -version 2>&1 | find "64-Bit" > nul 2>&1
if errorlevel 1 goto endBits
set serviceExe=bin\JavaService-x64.exe
:endBits

echo Using %serviceExe%

if "%1" == "install" goto INSTALL_SERVICE

if "%1" == "uninstall" goto UNINSTALL_SERVICE

goto BAD_CMD

rem ====================================================
rem Install as system service
rem ====================================================

:INSTALL_SERVICE

set JVM_DLL="%JAVA_HOME%\jre\bin\server\jvm.dll"
if not exist %JVM_DLL% goto MISSING_DLL

echo Using JVM %JVM_DLL%

if "%~2" == "" goto BAD_CMD
if "%~3" neq "" goto INSTALL_WITH_DEPENDENCIES

set cp="config;lib\*;lib\extra\*"

%serviceExe% -install "%2" %JVM_DLL% ^
%SVR_OPTS% %orb% %derby_cfg% %derby_log% -Djava.class.path=%cp% ^
-start com.addc.server.ServerRunner -method startService -params "${service.name}" ^
-stop com.addc.server.ServerRunner -method stopService ^
-out "%rootDir%\logs\out.log" -err "%rootDir%\logs\err.log" ^
-current "%rootDir%" -auto -overwrite -description "${service.name} as a Windows Service"

goto END

rem ====================================================
rem Install as system service with dependencies
rem ====================================================
:INSTALL_WITH_DEPENDENCIES

set cp="config;lib\*;lib\extra\*"

%serviceExe% -install "%2" %JVM_DLL% ^
%SVR_OPTS% %jmx% %orb% %derby_cfg% %derby_log% -Djava.class.path=%cp% ^
-start com.addc.secure.collector.StandAloneCollectorRunner -method startService -params "${service.name}" ^
-stop com.addc.secure.collector.StandAloneCollectorRunner -method stopService ^
-out "%rootDir%\logs\out.log" -err "%rootDir%\logs\err.log" ^
-current "%rootDir%" -depends %3 -auto -overwrite -description "${service.name} as a Windows Service"

goto END

rem ====================================================
rem Un-install System Service
rem ====================================================

:UNINSTALL_SERVICE

if "%~2" == "" goto BAD_CMD
%serviceExe% -uninstall "%2"

goto END


:BAD_CMD
echo Wrong number of parameters passed:
echo.
echo Usage:
echo   service install ^<service-name^> ^[dependency^] ^| uninstall ^<service-name^>
echo.
echo Where:
echo    install          : install ${service.name} with the given service-name as a Windows Service
echo    uninstall        : uninstall ${service.name} with the given service-name as a Windows Service
echo    service-name     : name that will be displayed in the Service Manager once installed
echo    dependency       : The name of a service that this service depends on
echo.
goto END

:MISSING_JAVA_HOME
echo.
echo JAVA_HOME has not been set, please set JAVA_HOME to point to a valid JDK.
echo.
goto END

:MISSING_DLL
echo.
echo Cannot find the server jvm.dll, please check your JAVA_HOME environment setting.
echo.
goto END

:END

endlocal
